#
# spec file for package perl-DateTime
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           perl-DateTime
Version:        1.12
Release:        3.5
%define cpan_name DateTime
Summary:        A date and time object for Perl
License:        Artistic-2.0
Group:          Development/Libraries/Perl
Url:            http://search.cpan.org/dist/DateTime/
Source:         http://www.cpan.org/authors/id/D/DR/DROLSKY/%{cpan_name}-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(DateTime::Locale) >= 0.41
BuildRequires:  perl(DateTime::TimeZone) >= 1.74
BuildRequires:  perl(Module::Build) >= 0.28
BuildRequires:  perl(Params::Validate) >= 0.76
BuildRequires:  perl(Test::Fatal)
BuildRequires:  perl(Test::More) >= 0.88
BuildRequires:  perl(Test::Warnings) >= 0.005
BuildRequires:  perl(Try::Tiny)
Requires:       perl(DateTime::Locale) >= 0.41
Requires:       perl(DateTime::TimeZone) >= 1.74
Requires:       perl(Params::Validate) >= 0.76
Requires:       perl(Try::Tiny)
%{perl_requires}

%description
DateTime is a class for the representation of date/time combinations, and
is part of the Perl DateTime project. For details on this project please
see the http://datetime.perl.org/ manpage. The DateTime site has a FAQ
which may help answer many "how do I do X?" questions. The FAQ is at the
http://datetime.perl.org/wiki/datetime/page/FAQ manpage.

It represents the Gregorian calendar, extended backwards in time before its
creation (in 1582). This is sometimes known as the "proleptic Gregorian
calendar". In this calendar, the first day of the calendar (the epoch), is
the first day of year 1, which corresponds to the date which was
(incorrectly) believed to be the birth of Jesus Christ.

The calendar represented does have a year 0, and in that way differs from
how dates are often written using "BCE/CE" or "BC/AD".

For infinite datetimes, please see the DateTime::Infinite module.

%prep
%setup -q -n %{cpan_name}-%{version}

%build
%{__perl} Build.PL installdirs=vendor optimize="%{optflags}"
./Build build flags=%{?_smp_mflags}

%check
./Build test

%install
./Build install destdir=%{buildroot} create_packlist=0
%perl_gen_filelist

%files -f %{name}.files
%defattr(-,root,root,755)
%doc Changes CREDITS leaptab.txt LICENSE README.md TODO

%changelog
* Mon Sep 15 2014 coolo@suse.com
- updated to 1.12
  - The last release had the wrong repo info in the metadata.
  - The latest historical changes in DateTime::TimeZone 1.74 caused some tests
  to fail. Reported by Slaven Rezic. RT #98483.
  - This release of DateTime.pm now requires the DateTime::TimeZone 1.74.
* Fri Jul 25 2014 coolo@suse.com
- updated to 1.10
  - Some tests added in 1.09 would fail on a Perl without a 64-bit
  gmtime(). Reported by Jerome Eteve. RT #95345.
  1.09   2014-05-03
  - A call to ->truncate( to => 'week' ) could fail but leave the object
  changed. RT #93347.
  - The value of ->jd() is now calculated based on ->mjd() instead of the other
  way around. This reduces floating point errors a bit when calculating MJD,
  and should have a neglible impact on the accuracy of JD. Reported by Anye
  Li. RT #92972. See the ticket for a more detailed description of what this
  fixes.
  - Attempting to construct a DateTime object with a year >= 5000 and a time
  zone other than floating or DST now issues a warning. This warning may go
  away once DateTime::TimeZone is made much faster. Inspired by a bug report
  from Lloyd Fournier. RT #92655.
  1.08   2014-03-11
  - DateTime now calls DateTime->_core_time() instead of calling Perl's time()
  built-in directly. This makes it much easier to override the value of time()
  that DateTime sees. This may make it easier to write tests for code that
  uses DateTime .
* Fri Mar  7 2014 coolo@suse.com
- updated to 1.07
  - Added a hack to get this module working on Android. RT #92671.
  - DateTime's attempt to generate infinity by calculating 9**9**9 actually got
  a number on some platforms, like powerpcspe. Reported by Gregor Hermann. RT
  [#91696].
  - Added a new CLDR ZZZZZ specifier, which is like ZZZ but inserts a
  colon. Patch by Ricardo Signes.
  - Added a new option for the truncate() method to truncate to the
  "local_week". This truncates to the locale's notion of the first day of the
  week, rather than always truncating to Monday. Patch by Christian Hansen.
* Tue Feb 11 2014 lchiquitto@suse.com
- removed obsolete patches:
  * DateTime-0.72-Build.patch
* Mon Dec  9 2013 coolo@suse.com
- updated to 1.04
  - Calling set_locale() or set_formatter() on an object with an ambiguous local
  time could change the underlying UTC time for that object. Reported by Marta
  Cuaresma Saturio. RT #90583.
* Tue Jun  4 2013 coolo@suse.com
- updated to 1.03
  - The set_time_zone() method was not returning the object when caalled with a
  name that matched the current zone. Reported by Noel Maddy. RT #84699.
  - When a constructor method like new() or today() was called on an object,
  you'd get an error message like 'Can't locate object method
  "_normalize_nanoseconds" via package "2013-04-15T00:00:00"'. This has been
  fixed to provide a sane error message. Patch by Doug Bell.
  - When set_time_zone() is called with a name that matches the current time
  zone, DateTime now short circuits and avoids a lot of work. Patch by Mark
  Stosberg.
  - Fixed test failures on older Perls.
  - Bumped the version to 1.00. This is mostly because my prior use of both X.YY
  and X.YYYY versions causes trouble for some packaging systems. Plus after 10
  years it's probably ready to be called 1.00. Requested by Adam. RT #82800.
  - The %%j specifier for strftime was not zero-padding 1 and 2 digit
  numbers. Fixed by Christian Hansen. RT #84310.
  - The truncate method was sloppy about validating its "to" parameter, so you
  could pass things like "years" or "month whatever anything goes". The method
  would accept the parameter but then not actually truncate the object. RT
  [#84229].
  - Previously, if a call to $dt->set_time_zone() failed it would still change
  the time zone of the object, leaving it in a broken state. Reported by Bill
  Moseley. RT #83940.
  - DateTime::Infinite objects should no longer die when methods that require a
  locale are called. Instead, these methods return undef for names and
  Inf/-Inf for numbers. This affects methods such as day_name() as well as
  CLDR and strftime formats. When a locale-specific format is used (like the
  "full" datetime format) it uses the en_US format. Reported by Paul
  Boldra. RT #67550.
  - Reverted the change to round nanoseconds up or down in various
  situtations. Now we always round down. This avoids the case where rounding
  up would require us to then increment the second value (which could then
  require us to increment the minute, which could then require us to increment
* Wed Feb 29 2012 ro@suse.de
- update DateTime-0.70-Build.patch
* Mon Feb 13 2012 coolo@suse.com
- updated to 0.72
  - Remove Test::DependentModules from the dep list. This is used by some
  author-only tests. Reported by Zefram.
  - There will be a new leap second on June 30, 2012.
* Fri Nov 18 2011 coolo@suse.com
- use original .tar.gz
* Mon May  9 2011 pascal.bleser@opensuse.org
- update to 0.70:
  * really fix %%N, finally
* Wed May  4 2011 pascal.bleser@opensuse.org
- update to 0.69:
  * when a DateTime object had nanoseconds == 0, the %%N strftime specifier
    always returned "0" regardless of the precision requested
* Mon Apr 25 2011 pascal.bleser@opensuse.org
- update to 0.68:
  * the tests for %%N in the last release relied on the vagaries of floating
    point math on a 64-bit system; now the from_epoch() method just uses string
    operations to separate the epoch into an integer value and a mantissa; this
    avoids floating point insanity (RT#67736)
- changes from 0.67:
  * the %%N strftime specifier simply truncated nanoseconds, rather than
    rounding them (RT#66744)
  * the %%U strftime specifier was off by one in years where January 1st was a
    Sunday (RT#67631)
  * the %%W strftime specifier was off by one in years where January 1st was a
    Sunday or Monday (RT#67631)
  * some small optimizations; the biggest impact is for calculating
    week_of_month, week_number, and week_year
  * now requires Perl 5.8.1+ (it implicitly did this anyway now that
    Params::Validate is 5.8.1+)
* Thu Mar 31 2011 pascal.bleser@opensuse.org
- disable tests on < 11.3, perl too old
* Sat Feb 19 2011 chris@computersalat.de
- update to 0.66
  - A bunch of documentation cleanup. No code changes.
- recreated by cpanspec 1.78.03
- add Build patch (<= 1120)
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Mon Nov 22 2010 anicka@suse.cz
- update to 0.65
  * All the constructors besides new() ended up calling new(), which meant that
  these constructors went through the parameter validation code
  twice. Avoiding this should make everything that constructs a new object
  (besides new() itself) a little faster.
  * The t/39no-so.t test failed for some people. I can't reproduce it, but this
  release will hopefully fix the problem. Patch by Tokuhiro Matsuno. RT
  [#62061].
  * Added a section on the DateTime Project ecosystem to the docs. Addresses RT
  [#60930].
  * Fixed wiki links in the docs now that the wiki has moved to a new wiki
  platform.
  * Restored some of the dzil-ification. The repo now has a very minimal
  Build.PL file which is just enough to build the XS code and run the
  tests. This fixes the total lack of prereqs in the META.* files. Reported by
  Bjørn-Olav. RT #62427.
* Thu Sep 30 2010 anicka@suse.cz
- update to 0.63
  * Don't try to test with DateTime::Format::Strptime unless we
  have a relatively recent version. Should fix some test failures.
* Fri Sep 17 2010 chris@computersalat.de
- update to 0.61
  - Switching to dzil in 0.56 broke the --pp flag for the Build.PL. Reported by
    Jonathan Noack. RT #59421.
- changed bcond_with test -> pod
* Thu Jul  8 2010 chris@computersalat.de
- update to 0.60
  - By default, Dist::Zilla generates a Build.PL that requires Module::Build
    0.3601+, but this distro really doesn't need any particular version.
- hence removed MB patch
* Fri Jul  2 2010 chris@computersalat.de
- update to 0.59
  - More packaging fixes. This release makes sure that POD only shows up in the
    right files. In 0.56 through 0.58, some POD in the wrong place confused the
    search.cpan.org POD display code, and the main module's documentation wasn't
    viewable.
- 0.58   2010-06-28
  - Versions 0.56 and 0.57 did not build XS properly when installing.
- 0.57   2010-06-26
  - Make DateTime::LeapSecond have the same $VERSION as every other .pm file.
- 0.56   2010-06-26
  - The set_formatter() method did not return the DateTime object, and did not
    actually validate the value provided for the formatter. Based on a patch by
    Andrew Whatson. RT #58506.
  - Improved docs on floating time zone. Based on suggestions by Michael
    Svoboda. RT #56389.
  - Added mention of end-of-month algorithms to docs on DateTime math. Based on
    a patch by Michael R. Davis. RT #58533.
  - License is now Artistic 2.0.
- added MB patch
  o Author Requires Module::Build >= 0.3601
    but 1120 does not provide it, and builds just fine with Module::Build 0.280801
* Sun Apr 11 2010 chris@computersalat.de
- update to 0.55
  - Get all tests passing on 5.6.2. Thanks to Zefram for help spotting the
    problems.
  - Moved code to my hg repo at http://hg.urth.org/hg/DateTime.pm.
- 0.54   2010-03-14
  - Bumped the DateTime::TimeZone prereq to 1.09 to force people to use a modern
    version. Previously the minimum version was 0.59, and there have been a lot
    of bug fixes since then.
  - String overloading now extends to string comparison, so a DateTime object
    can be compared to any string. In other words
    if ( $dt eq $string ) { ... }
    will simply stringify $dt and then do a normal string-is-equals
    check. Previously, this would blow up unless both operands were a DateTime
    object.
    Note that future versions of Test::More (0.95_01+) will no longer stringify
    arguments to is(), which means that older versions of DateTime may cause new
    test failures when you upgrade Test::More. It is highly recommended that you
    upgrade DateTime before upgrading to Test::More 0.95_01+.
    Patch by Michael Schwern. RT #55453.
  - Allow passing end_of_month setting to $duration->inverse(). Requested by
    John Siracusa. RT #53985.
- fixed deps
  - perl-macros < 1120
  - perl(Test::Exception)
  - perl(Test::More) >= 0.88
  - perl(DateTime::TimeZone) >= 1.09
- split package to DateTime_0_53 for suse_version < 1120
* Sun Apr 11 2010 chris@computersalat.de
- update to 0.53
  - Added Test::Exception to build_requires.
- 0.52   2009-12-05
  - Numeric to ->new() are now all validated to make sure they are
    integers. Previously, things like "month => 11.2" would have been
    allowed. Based on a bug report from Max Kanat-Alexandar. RT #45767.
  - Added a warning to the docs suggesting that you cache the locale time zone
    if you need to make many DateTime objects in the local zone. Looking up the
    local zone can be fairly expensive. RT #46753.
- 0.51   2009-11-01
  - Switched to Module::Build. To force a non-XS build, start the build
    process with "perl Build.PL --pp".
  - POD-related tests are only run for the maintainer now.
  - Fixed handling of negative years in CLDR formatting for "y" and "u"
    patterns. Note that the LDML spec says nothing about how this should work,
    so I took my best guess.
- cleanup spec
  o removed useless comments
  o fixed Header
  o update License, Url, description
  o moved changelog to changes file
  o macro usage
  o Makefile.PL > Build.PL
  o changelog to changes file
* Sat Jul 25 2009 chris@computersalat.de
- spec mods
  * removed ^----------
  * removed ^#---------
* Sun Jun 21 2009 chris@computersalat.de
- update to 0.50
  - 0.50   2009-05-11
  - Tests were failing on Win32 because they attempted to use a negative
    epoch. Fixed so that these tests are skipped. Fixes RT #45966.
  - 0.49   2009-05-04
  - A bug in the test code for handling overloaded objects in from_epoch
    resulted in a test failure on Perl 5.8.x. This release contains no
    changes besides a test code fix.
  - 0.48   2009-05-04
  - Some of the accessors (the "main" ones like year(), month(), day(),
    etc) now warn if they are passed a value. Patch from Shawn
    Moore. Fixes RT #6979.
  - DateTime::Duration expected DateTime to be loaded and used some
    constants from it, but did not explicitly "use DateTime". Reported
    by Jeff Kubina. RT #44740.
  - The CLDR formatting for "c" and "cc" was incorrectly using the local
    day of the week. This meant that it gave the wrong result for
    locales where Monday is not considered the first day of the
    week. Reported by Maros Kollar. RT #45007.
  - DateTime->from_epoch did not allow an object which overloaded
    numification as the epoch value. Patch by Michael Schwern. RT
    [#45653].
  - Fixed how datetime subtraction is handled for some cases around DST
    changes. This had been improved back in 0.30, but there were still
    bugs. RT #45235.
  - 0.47   2009-03-01
  - The handling of CLDR format 'j' and 'jj' was backwards, using 24
    hour time for locales that wanted 12 hour, and vice versa. Reported
    by Maros Kollar.
  - The CLDR formatting was missing support for lower-case "q"
    patterns. Reported by Maros Kollar.
  - 0.46   2009-02-28
  - Added a duration_class method for the benefit of DateTime.pm
    subclasses. Patch by Shawn Moore.
  - 0.4501 2008-11-25
  - The epoch() method got broken in the recent shuffling between
    Time::Local and Time::y2038. Unfortunately, the tests to catch this
    also got lost in the shuffle. Reported by Avianna Chao.
  - 0.45   2008-11-11
  - Reverted the changes to use Time::y2038, on the recommendation of
    Michael Schwern (the author of said module), because it is not yet
    stable. This may come back in a future release.
  - 0.4401 2008-11-03
  - In order to handle epochs > 2**32 properly on a 32-bit machine, we
    also need to import gmtime from Time::y2038. This changes fixes a
    whole bunch of test failures seen with 0.44.
  - 0.44   2008-11-01
  - XS-capable DateTime.pm now uses Time::y2038 instead of
    Time::Local. This lets it handle epochs up to 142 million years
    before and after the Unix epoch.
  - Fixed a compiler warning with Perl 5.10.0.
  - Fixed docs for year_with_era, which had AD and BC
    backwards. Reported by Vynce Montgomery. RT #39923.
  - The format_cldr() method did not format the "yy" format properly
    when the year ended in "0X". Reported by Wilson Santos. RT #40555.
  - 0.4305 2008-10-03
  - The pure Perl version of this module did not know about the end of
    2008 leap second. Reported by James T Monty.
  - 0.4304 2008-07-13
  - Fix test failures when tests are run with DateTime::Locale
    0.41. Reported by David Cantrell via CPAN Testers.
  - 0.4303 2008-07-12
  - There is a new leap second coming at the end of 2008.
- added perl-macros
  o autogen filelist with perl_gen_filelist
- spec mods
  o added header
  o fixed deps
* Tue Jun  3 2008 pascal.bleser@opensuse.org
- new package
